# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


def validate_listvalue(values):
    """
    Property: DataValue.ListValue
    """
    from .. import AWSHelperFn
    from ..iottwinmaker import DataValue

    if not isinstance(values, list):
        raise TypeError("ListValue must be a list")

    for v in values:
        if not isinstance(v, (DataValue, AWSHelperFn)):
            raise TypeError("ListValue must contain DataValue or AWSHelperFn")


def validate_nestedtypel(value):
    """
    Property: DataType.NestedType
    """
    from .. import AWSHelperFn
    from ..iottwinmaker import DataType

    if not isinstance(value, (DataType, AWSHelperFn)):
        raise TypeError("NestedType must be either DataType or AWSHelperFn")



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType, Tags
from .validators.codeartifact import policytypes


class Domain(AWSObject):
    """
    `Domain <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeartifact-domain.html>`__
    """

    resource_type = "AWS::CodeArtifact::Domain"

    props: PropsDictType = {
        "DomainName": (str, True),
        "EncryptionKey": (str, False),
        "PermissionsPolicyDocument": (policytypes, False),
        "Tags": (Tags, False),
    }


class Repository(AWSObject):
    """
    `Repository <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeartifact-repository.html>`__
    """

    resource_type = "AWS::CodeArtifact::Repository"

    props: PropsDictType = {
        "Description": (str, False),
        "DomainName": (str, True),
        "DomainOwner": (str, False),
        "ExternalConnections": ([str], False),
        "PermissionsPolicyDocument": (policytypes, False),
        "RepositoryName": (str, True),
        "Tags": (Tags, False),
        "Upstreams": ([str], False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class AvailSuppression(AWSProperty):
    """
    `AvailSuppression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-availsuppression.html>`__
    """

    props: PropsDictType = {
        "Mode": (str, False),
        "Value": (str, False),
    }


class Bumper(AWSProperty):
    """
    `Bumper <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-bumper.html>`__
    """

    props: PropsDictType = {
        "EndUrl": (str, False),
        "StartUrl": (str, False),
    }


class CdnConfiguration(AWSProperty):
    """
    `CdnConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-cdnconfiguration.html>`__
    """

    props: PropsDictType = {
        "AdSegmentUrlPrefix": (str, False),
        "ContentSegmentUrlPrefix": (str, False),
    }


class DashConfiguration(AWSProperty):
    """
    `DashConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-dashconfiguration.html>`__
    """

    props: PropsDictType = {
        "ManifestEndpointPrefix": (str, False),
        "MpdLocation": (str, False),
        "OriginManifestType": (str, False),
    }


class LivePreRollConfiguration(AWSProperty):
    """
    `LivePreRollConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-liveprerollconfiguration.html>`__
    """

    props: PropsDictType = {
        "AdDecisionServerUrl": (str, False),
        "MaxDurationSeconds": (integer, False),
    }


class AdMarkerPassthrough(AWSProperty):
    """
    `AdMarkerPassthrough <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-admarkerpassthrough.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
    }


class ManifestProcessingRules(AWSProperty):
    """
    `ManifestProcessingRules <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-manifestprocessingrules.html>`__
    """

    props: PropsDictType = {
        "AdMarkerPassthrough": (AdMarkerPassthrough, False),
    }


class PlaybackConfiguration(AWSObject):
    """
    `PlaybackConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediatailor-playbackconfiguration.html>`__
    """

    resource_type = "AWS::MediaTailor::PlaybackConfiguration"

    props: PropsDictType = {
        "AdDecisionServerUrl": (str, True),
        "AvailSuppression": (AvailSuppression, False),
        "Bumper": (Bumper, False),
        "CdnConfiguration": (CdnConfiguration, False),
        "ConfigurationAliases": (dict, False),
        "DashConfiguration": (DashConfiguration, False),
        "LivePreRollConfiguration": (LivePreRollConfiguration, False),
        "ManifestProcessingRules": (ManifestProcessingRules, False),
        "Name": (str, True),
        "PersonalizationThresholdSeconds": (integer, False),
        "SlateAdUrl": (str, False),
        "Tags": (Tags, False),
        "TranscodeProfileName": (str, False),
        "VideoContentSourceUrl": (str, True),
    }


class HlsConfiguration(AWSProperty):
    """
    `HlsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediatailor-playbackconfiguration-hlsconfiguration.html>`__
    """

    props: PropsDictType = {
        "ManifestEndpointPrefix": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags


class ServerSideEncryptionConfiguration(AWSProperty):
    """
    `ServerSideEncryptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-voiceid-domain-serversideencryptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "KmsKeyId": (str, True),
    }


class Domain(AWSObject):
    """
    `Domain <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-voiceid-domain.html>`__
    """

    resource_type = "AWS::VoiceID::Domain"

    props: PropsDictType = {
        "Description": (str, False),
        "Name": (str, True),
        "ServerSideEncryptionConfiguration": (ServerSideEncryptionConfiguration, True),
        "Tags": (Tags, False),
    }
